@@ -5,7 +5,7 @@ use salvo::prelude::*;
 
 #[fn_handler]
 async fn index(res: &mut Response) {
-    res.render_html_text(INDEX_HTML);
+    res.render(Text::Html(INDEX_HTML));
 }
 
 #[fn_handler]
@@ -17,15 +17,15 @@ async fn upload(req: &mut Request, res: &mut Response) {
             let dest = format!("temp/{}", file.file_name().unwrap_or_else(|| "file".into()));
             if let Err(e) = std::fs::copy(&file.path(), Path::new(&dest)) {
                 res.set_status_code(StatusCode::INTERNAL_SERVER_ERROR);
-                res.render_plain_text(&format!("file not found in request: {}", e.to_string()));
+                res.render(Text::Plain(format!("file not found in request: {}", e.to_string())));
             } else {
                 msgs.push(dest);
             }
         }
-        res.render_plain_text(&format!("Files uploaded:\n\n{}", msgs.join("\n")));
+        res.render(Text::Plain(format!("Files uploaded:\n\n{}", msgs.join("\n"))));
     } else {
         res.set_status_code(StatusCode::BAD_REQUEST);
-        res.render_plain_text("file not found in request");
+        res.render(Text::Plain("file not found in request"));
     }
 }
 
